#!/usr/bin/perl -w
#
# Makes an html report of your films.
#
# Film entry format (only title is mandatory):
# Title;IMDB id;Notes
#
# Run as makeFilmPage.pl film_list > myFilms.html
#
# Dependency: Cache::Cache

use strict;
use IMDB::Film;
use LWP::Simple;
use Cache::FileCache;

my $cache = new Cache::FileCache();

#my $q = new CGI;

print "<html><head><title>Film list</title><link rel=\"stylesheet\" href=\"style.css\"></head><body><h1>Films</h1>";

my @list;
while(<>){
    if(/^\s*$/){next;}
    push @list, $_;
}

my @notFound;
my @movies;

my %notes;
my %imgFilenames;

foreach $_ (sort @list){
    my ($title, $code, $notes) = split(/;/);
    
    my $movie;

    print STDERR "--> Looking for $title...";

    if(defined $code and $code ne "" and $code != 0) {
	  $movie = $cache->get($code);
	  if(not defined $movie){
		$movie = new IMDB::Film(crit => $code);
		if(defined $movie){
		    $cache->set($code, $movie, "never");
		}
	  } else {
		print STDERR "*** found in cache *** ";
	  }
    } else {
	  $movie = $cache->get($title);
	  if(not defined $movie){
		eval('$movie = new IMDB::Film(crit => $title)');
		if(defined $movie){
		    $cache->set($title, $movie, "never");
		}
	  } else {
		print STDERR "*** found in cache *** ";
	  }
    }
    
    if(defined $movie){

	  print STDERR "found ".$movie->title."\n";

	  #save film image
	  my $imgFilename = "film_images/".$movie->code.'.jpg';
	  $imgFilename =~ s/\n//;

	  if(defined $movie->cover and $movie->cover ne ""){
		if(!(-e "film_images/")){mkdir "film_images";}
		if(!(-e $imgFilename)) {
		    print STDERR "retrieving ".$movie->cover.": ";
		    print STDERR getstore($movie->cover, $imgFilename);
		    print "\n";
		}
	  } else {
		if(!(-e "film_images/")){mkdir "film_images";}
		$imgFilename = "film_images/no_image.jpg";
	  }

	  $notes{$movie->title} = $notes;
	  push @movies, $movie;

    } else {
	  push @notFound, $title;
	  print STDERR "\n";
    }
}

my $middle = (scalar @movies)/2;

#make links
print '<table border="0">';
print '<tr><td valign="top"><ul>';
foreach my $movie (sort {uc($a->title) cmp uc($b->title)} @movies[0..$middle]){
    print '<li><a href="#'.$movie->title.'">'.$movie->title.'</a></li>';
}

$middle++;

print '</ul></td><td valign="top"><ul>';
foreach my $movie (sort {uc($a->title) cmp uc($b->title)} @movies[$middle..(scalar @movies - 1)]){
    #print STDERR $movie->title;
    print '<li><a href="#'.$movie->title.'">'.$movie->title.'</a></li>';
}
print "</ul></td></tr>";
print '</table>';

print '<br /><br />';

foreach my $movie (sort {uc($a->title) cmp uc($b->title)} @movies){
    #print entry
    print "<a name=\"".$movie->title."\"></a>";
    print "<div class=\"film_entry\">";
    printMovieEntry($movie, $notes{$movie->title});
    print "</div>";

}

if(scalar @notFound > 0) {
    print "<b>Also:</b><ul>".join("", map("<li>$_</li>", @notFound))."</ul>";
}

print "</body></html>";

sub printMovieEntry{
    my($movie, $notes) = @_;

    print "<table border=\"0\"><tr>";

    my $imgFilename = 'film_images/'.$movie->code.'.jpg';
    $imgFilename =~ s/\n//;
    if(!(-e $imgFilename)){
	  $imgFilename = 'film_images/no_image.jpg';
    }

    print "<td valign=\"top\"><div class=\"film_image\"><img border=\"0\" src=\"".$imgFilename."\"></div></td><td valign=\"top\">";
    print "<span class=\"title\">".$movie->title."</span> (".$movie->year.")";
    print " <a href=\"http://www.imdb.com/title/tt".$movie->code."\">imdb</a>";
    print "<br />";
    print $movie->duration;
    print "<br />";
    print "<b>directed by:</b> ".join('; ', map {$_->{"name"}} @{$movie->directors});
    print "<br />";
    if(scalar @{$movie->writers} > 0){
	  print "<b>written by:</b> ".join('; ', map {$_->{"name"}} @{$movie->writers});
	  print "<br />";
    }
    print "<b>produced in:</b> ".join('; ', @{$movie->country});
    my $s = (scalar @{$movie->language} > 1)?'s':'';
    print " (language$s: ".join('; ', @{$movie->language}).")";
    print "<br />";

    if(defined $notes and $notes ne ""){
	  print "<br />";
	  print "<b>notes:</b> $notes<br />";
    }

    print "</td></tr></table>";
}
